v0.3.0 - 2018-03-11
===================

- Update for toolrack 2.0.1.
- Use pathlib.Path internally instead of plain strings.
- Add ``ParsedDirectory``.
- Add ``ProcPIDNs`` to return namespace IDs for processes.


v0.2.0 - 2017-11-02
===================

- Add ``CommandNameFilter`` process filter.


v0.1.0 - 2017-10-07
===================

- First release.
